@@ -5,8 +5,6 @@ use warnings;
 use Carp;
 use LWP::UserAgent;
 use HTTP::Request;
-use HTML::Strip;
-use XML::Simple;
 
 use parent 'LyricFinder::_Class';
 
@@ -99,14 +97,14 @@ sub _parse {
 	my $xmldoc;
 	my $xs1 = XML::Simple->new();
 
-	eval {$xmldoc = $xs1->XMLin($html); };
+	eval {$xmldoc = $xs1->XMLin($html, ForceArray => ['SearchLyricResult']); };
 	unless ($xmldoc && !$@ && $xmldoc->{'SearchLyricResult'}) {
 		carp($self->{'Error'} = "e:$Source - No xml returned ($@) - no match.");
 		return '';
 	}
 
 	my $lyricID = 0; my $lyricChecksum = 0;
-	for (my $i=0;$i<=$#{$xmldoc->{'SearchLyricResult'}};$i++) {
+	for (my $i=0;$i<$#{$xmldoc->{'SearchLyricResult'}};$i++) {
 		if ($xmldoc->{'SearchLyricResult'}->[$i]->{'Artist'} =~ /^$artist_in$/i
 				&& $xmldoc->{'SearchLyricResult'}->[$i]->{'Song'} =~ /^$song_in/i
 				&& $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricId'}
@@ -118,7 +116,7 @@ sub _parse {
 		}
 	}
 	unless ($lyricID && $lyricChecksum) {
-		for (my $i=0;$i<=$#{$xmldoc->{'SearchLyricResult'}};$i++) {
+		for (my $i=0;$i<$#{$xmldoc->{'SearchLyricResult'}};$i++) {
 			if ($xmldoc->{'SearchLyricResult'}->[$i]->{'Artist'} =~ /$artist_in/i
 					&& $xmldoc->{'SearchLyricResult'}->[$i]->{'Song'} =~ /^$song_in/i
 					&& $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricId'}
@@ -158,14 +156,14 @@ sub _parse {
 		my $text = $xmldoc->{'Lyric'};
 		$self->{'image_url'} = $xmldoc->{'LyricCovertArtUrl'};
 		$self->_debug("--cover art url=".$self->{'image_url'}."=");
-		return $text  if ($text =~ /[a-z]/i);
+		return $self->_normalize_lyric_text($text)  if ($text =~ /[a-z]/i);
 
 		carp($self->{'Error'} = "e:$Source - Failed to identify lyrics on result page.");
 		return '';
 	} else {
 		my $Source = $self->{'Source'};
 		if ($res->status_line =~ /^404/) {
-			$self->{'Error'} = "..$Source - Lyrics not found.";
+			$self->{'Error'} = "..$Source - Lyrics not found (Server Error 404).";
 		} else {
 			carp($self->{'Error'} = "e:$Source - Failed to retrieve ".$self->{'Url'}
 					.' ('.$res->status_line.').');
@@ -437,7 +435,7 @@ file fetched.
 
 =head1 DEPENDENCIES
 
-L<HTML::Strip>, L<HTTP::Request>, L<LWP::UserAgent>
+L<XML::Simple>, L<HTTP::Request>, L<LWP::UserAgent>
 
 =head1 BUGS
 
